%function mul_rays(zwb,zref,vw,vr,hh,cmp)
%
%-----------------------------------------------------------------------
% DESCRIPTION
%	program to compute the traveltimes and plot the rays of primaries
%	and specularly-reflected multiples from a two flat-layer model.
%------------------------------------------------------------------
%	Input:
%		zwb:	depth of the flat water bottom (m)
%		zref:	depth of the flat reflector (m)
%		vw:		water velocity (m/s)
%		vr:		sediment velocity (m/s)
%		hh:		offset (m)
%		cmp:    cmp (m)
%
%	Output:
%		plot of primaries and multiples
%
%	Examples:
%		mul_rays(500,800,1500,2500,1000,2000)
%---------------------------------------------------------------------
clear
clf
	% set parameters 
	zwb=500;
	zref=800;
	vw=1500;
	vr=2500;
	hh=1000;
	cmp=2000;

	%% compute auxiliary variables
	rho=vr/vw;
	zwb2=zwb^2;
	thref=zref-zwb;
	thref2=thref^2;
	hh=hh/2;			% half offset
	hh2=hh^2;

	% water-bottom primary
	xp(1)=cmp-hh;					zp(1)=0;
	xp(2)=cmp;						zp(2)=zwb;
	xp(3)=cmp+hh;					zp(3)=0;

	%
	% primary from the sediment reflector.
	% The 121 refers to bounces at reflectors 1, 2 and 1
	%
	x121(1)=cmp-hh;					z121(1)=0;
	%
	% first reflection point at the water-bottom
	if (hh==0)
		temp=0;
	else
		temp=solve_for_x1(rho,hh,zwb,thref,1)
	end
	x121(2)=cmp-hh+temp; 			z121(2)=zwb;
	% reflection point at the second reflector
	x121(3)=cmp;					z121(3)=zref;
	% second reflection point at the water-bottom
	x121(4)=cmp+hh-temp;			z121(4)=zwb;
	% emergence point at the surface
	x121(5)=cmp+hh;					z121(5)=0;

	%
	% first order WB multiple
	%
	x101(1)=cmp-hh;					z101(1)=0;
	x101(2)=cmp-hh/2;				z101(2)=zwb;
	x101(3)=cmp;					z101(3)=0;
	x101(4)=cmp+hh/2;				z101(4)=zwb;
	x101(5)=cmp+hh;					z101(5)=0;

	%
	% second order WB multiple
	%
	x10101(1)=cmp-hh;				z10101(1)=0;
	x10101(2)=cmp-2*hh/3;			z10101(2)=zwb;
	x10101(3)=cmp-hh/3;				z10101(3)=0;
	x10101(4)=cmp;					z10101(4)=zwb;
	x10101(5)=cmp+hh/3;				z10101(5)=0;
	x10101(6)=cmp+2*hh/3;			z10101(6)=zwb;
	x10101(7)=cmp+hh;				z10101(7)=0;

	%
	% first order surface multiple of the second layer
	%
	x1210121(1)=cmp-hh;				z1210121(1)=0;
	% first reflection point at the water-bottom
	if (hh==0)
		temp=0;
	else
		temp=solve_for_x1(rho,hh/2,zwb,thref,1);
	end
	x1210121(2)=cmp-hh+temp;		z1210121(2)=zwb;
	% first reflection point at the deep reflector
	x1210121(3)=cmp-hh/2;			z1210121(3)=zref;
	% second reflection point at the water bottom
	x1210121(4)=cmp-temp;			z1210121(4)=zwb;
	% reflection point at the surface
	x1210121(5)=cmp;				z1210121(5)=0;
	% third reflection point at the water bottom
	x1210121(6)=cmp+temp;			z1210121(6)=zwb;
	% second reflection at the deep reflector 
	x1210121(7)=cmp+hh/2;			z1210121(7)=zref;
	% fourth reflection point at the water bottom
	x1210121(8)=cmp+hh-temp;		z1210121(8)=zwb;
	% emergence point at the surface
	x1210121(9)=cmp+hh;				z1210121(9)=0;

	%
	% first order internal multiple of the second layer
	%
	% first reflection point at the water-bottom
	x12121(1)=cmp-hh;				z12121(1)=0;
	if (hh==0)
		temp=0;
	else
		temp=solve_for_x1(rho,hh,zwb,2*thref,1);
	end
	x12121(2)=cmp-hh+temp;			z12121(2)=zwb;
	% first reflection point at the deep reflector
	x12121(3)=cmp-(hh-temp)/2;		z12121(3)=zref;
	% second bounce at the water-bottom
	x12121(4)=cmp;					z12121(4)=zwb;
	% second bounce at the deep reflector
	x12121(5)=cmp+(hh-temp)/2;		z12121(5)=zref;
	% third bounce at the water-bottom
	x12121(6)=cmp+hh-temp;			z12121(6)=zwb;
	% emergence point at the surface
	x12121(7)=cmp+hh;				z12121(7)=0;

	%
	% peg-leg multiple of the second layer
	%
	x12101(1)=cmp-hh;				z12101(1)=0;
	% first reflection point at the water-bottom
	if (hh==0)
		temp=0;
	else
		temp=solve_for_x1(rho,hh,zwb,thref,2)
	end
	x12101(2)=cmp-hh+temp;			z12101(2)=zwb;
	% first reflection at the deep reflector
	x12101(3)=cmp-hh+(hh-temp);	z12101(3)=zref;
	% second reflection at the water bottom
	x12101(4)=cmp-hh+(2*hh-3*temp);	z12101(4)=zwb;
	% reflection at the surface
	x12101(5)=cmp-hh+(2*hh-2*temp);	z12101(5)=0;
	% third reflection at the water bottom
	x12101(6)=cmp+hh-temp;			z12101(6)=zwb;
	% emergence point at the surface
	x12101(7)=cmp+hh;				z12101(7)=0;

	% make plot of rays
	xmin=cmp-hh;
	xmax=cmp+hh;
	figure;
	subplot(2,2,1)
	axis ij;
	hold on;
	plot([xmin xmax],[0.1 0.1],'k','LineWidth',2);
	plot([xmin xmax],[zwb zwb],'k','LineWidth',2);
	plot([xmin xmax],[zref zref],'k','LineWidth',2);
	plot(xp,zp,'b','LineWidth',2);
	plot(x121,z121,'r','LineWidth',2);
	plot(cmp-hh,0.1,'*r');
	plot(cmp+hh,0.1,'vg');
	title('Primaries');
	ylabel('Depth (m)');
	subplot(2,2,2)
	axis ij;
	hold on;
	plot([xmin xmax],[0.1 0.1],'k','LineWidth',2);
	plot([xmin xmax],[zwb zwb],'k','LineWidth',2);
	plot([xmin xmax],[zref zref],'k','LineWidth',2);
	plot(cmp-hh,0.1,'*r');
	plot(cmp+hh,0.1,'vg');
	plot(x101,z101,'b','LineWidth',2);
	%plot(x10101,z10101,'r','LineWidth',2);
	plot(x1210121,z1210121,'g','LineWidth',2);
	title('Surface multiples');
	subplot(2,2,3)
	axis ij;
	hold on;
	plot([xmin xmax],[0.1 0.1],'k','LineWidth',2);
	plot([xmin xmax],[zwb zwb],'k','LineWidth',2);
	plot([xmin xmax],[zref zref],'k','LineWidth',2);
	plot(cmp-hh,0.1,'*r');
	plot(cmp+hh,0.1,'vg');
	plot(x12121,z12121,'LineWidth',2);
	title('Internal multiple');
	ylabel('Depth (m)');
	xlabel('CMP position (m)');
	subplot(2,2,4)
	axis ij;
	hold on;
	plot([xmin xmax],[0.1 0.1],'k','LineWidth',2);
	plot([xmin xmax],[zwb zwb],'k','LineWidth',2);
	plot([xmin xmax],[zref zref],'k','LineWidth',2);
	plot(cmp-hh,0.1,'*r');
	plot(cmp+hh,0.1,'vg');
	plot(x12101,z12101,'LineWidth',2);
	title('Pegleg multiple');
	xlabel('CMP position (m)');
